@@ -35,7 +35,7 @@ from bokeh.plotting import figure
 from bokeh.transform import cumsum, dodge
 from pandas.core.base import PandasObject
 
-from .base import embedded_html, show, set_fontsizes_of_figure
+from .base import embedded_html, set_fontsizes_of_figure, show
 from .geoplot import geoplot
 
 
@@ -180,18 +180,18 @@ def plot(
     --------
     >>> df.plot_bokeh.line()
     >>> df.plot_bokeh.scatter(x='x',y='y')
-    
+
     These plotting methods can also be accessed by calling the accessor as a
     method with the ``kind`` argument (except of "map" plot):
     ``df.plot_bokeh(kind='line')`` is equivalent to ``df.plot_bokeh.line()``
 
     For more information about the individual plot kind implementations, have a
     look at the underlying method accessors (like df.plot_bokeh.line) or visit
-    https://github.com/PatrikHlobil/Pandas-Bokeh. 
+    https://github.com/PatrikHlobil/Pandas-Bokeh.
 
     If `sizing_mode` is not fixed (default), it will overide the set plot width or height
     depending on which axis it is scaled on.
-    
+
     """
 
     # Make a local copy of the DataFrame:
@@ -925,7 +925,6 @@ def plot(
         fontsize_legend=fontsize_legend,
     )
 
-
     # Scientific formatting for axes:
     if disable_scientific_axes is None:
         pass
@@ -1649,12 +1648,10 @@ def pieplot(
         source["inner_radius"] = [inner_radius] * len(source["__x__values"])
         source["outer_radius"] = [outer_radius] * len(source["__x__values"])
 
-        if bokeh.__version__ < "1.4":
-            legend_parameter_name = "legend"
-        else:
-            legend_parameter_name = "legend_label"
+        legend_parameter_name = "legend_field"
         if i == 0:
-            kwargs[legend_parameter_name] = "__x__values"
+            kwargs[legend_parameter_name] = "__x__values_original"
+            print(kwargs[legend_parameter_name])
         else:
             kwargs.pop(legend_parameter_name, None)
 
@@ -1821,7 +1818,7 @@ class FramePlotMethods(BasePlotMethods):
 
         Returns
         -------
-        
+
         Bokeh.plotting.figure or Bokeh.layouts.row
 
         Examples
@@ -1872,7 +1869,7 @@ class FramePlotMethods(BasePlotMethods):
 
         Returns
         -------
-        
+
         Bokeh.plotting.figure or Bokeh.layouts.row
 
         Examples
@@ -1923,7 +1920,7 @@ class FramePlotMethods(BasePlotMethods):
 
         Returns
         -------
-        
+
         Bokeh.plotting.figure or Bokeh.layouts.row
 
         Examples
@@ -2297,9 +2294,9 @@ class FramePlotMethods(BasePlotMethods):
             The column name or column position to be used as vertical
             coordinates for each point.
 
-        category : str or object 
+        category : str or object
             A column name whose values will be used to color the
-            marker points according to a colormap. 
+            marker points according to a colormap.
 
         **kwds
             Keyword arguments to pass on to :meth:`pandas.DataFrame.plot_bokeh`.
@@ -2425,7 +2422,7 @@ class FramePlotMethods(BasePlotMethods):
 def _initialize_rangetool(p, x_axis_type, source):
     """
     Initializes the range tool chart and slider.
-    
+
     Parameters
     ----------
     p : Bokeh.plotting.figure
